@@ -18,29 +18,6 @@ def _decode_str(decoder, msg):
     return msg
 
 
-red = "\u001b[31m"
-green = "\u001b[32m"
-yellow = "\u001b[33m"
-blue = "\u001b[34m"
-magenta = "\u001b[35m"
-cyan = "\u001b[36m"
-white = "\u001b[37m"
-reset = "\u001b[0m"
-
-
-def _color_status(status):
-    if status == "PASS":
-        return f"{green}{status}{reset}"
-    elif status == "NOT RUN":
-        return f"{cyan}{status}{reset}"
-    else:
-        return f"{red}{status}{reset}"
-
-
-def _color_name(status):
-    return f"{yellow}{status}{reset}"
-
-
 def _decode(message_definition, level_diff=0):
     names = []
     name_to_decode = {}
