@@ -67,12 +67,16 @@ class _KeywordData(_AbstractKeywordData):
     def name(self):
         return self.attrs.get("name")
 
+    @property
+    def library(self):
+        return self.attrs.get("library")
+
     @property
     def type(self):
         return "KEYWORD"
 
     def __str__(self):
-        return f"_KeywordData({self.name})"
+        return f"_KeywordData({self.library} {self.name})"
 
     __repr__ = __str__
 
@@ -305,7 +309,8 @@ class _XmlSaxParser(xml.sax.handler.ContentHandler):
             )
 
             self._listener.end_suite(
-                s.attrs["name"], {"status": status, "timedelta": -1}
+                s.attrs["name"],
+                {"status": status, "timedelta": -1, "id": s.attrs["id"]},
             )
 
     def start_test(self, attrs):
@@ -330,6 +335,7 @@ class _XmlSaxParser(xml.sax.handler.ContentHandler):
             self._listener.end_test(
                 s.attrs["name"],
                 {
+                    "id": s.attrs["id"],
                     "status": status,
                     "timedelta": s.status.compute_end_timedelta(
                         self._listener.initial_time
@@ -405,11 +411,13 @@ class _XmlSaxParser(xml.sax.handler.ContentHandler):
             self._listener.end_keyword(
                 s.name,
                 {
+                    "kwname": s.name,
                     "status": status,
                     "timedelta": s.status.compute_end_timedelta(
                         self._listener.initial_time
                     ),
                     "message": "",
+                    "libname": getattr(s, "library", None),
                 },
             )
 
